@@ -339,16 +339,16 @@ def fetch_binance_ohlc(symbol = 'BTCUSDT', frequence = '1d', public_key = None,
         binance_df['close'] = binance_df['close'].astype(float)
         binance_df['high'] = binance_df['high'].astype(float)
         binance_df['low'] = binance_df['low'].astype(float)
-        save_equity_daily_data(data_df = binance_df, ticker = symbol, starting_date=start_time, running_date = end_time, local_root_directory = local_root_directory)
+        save_equity_daily_data(data_df = binance_df, ticker = symbol, frequence=frequence, starting_date=start_time, running_date = end_time, local_root_directory = local_root_directory)
     else :
-        filename = symbol + '_' + start_time.strftime('%d_%b_%Y') + '_' + end_time.strftime(
+        filename = symbol + '_' + frequence + '_' + start_time.strftime('%d_%b_%Y') + '_' + end_time.strftime(
             '%d_%b_%Y') + '_daily_returns.pkl'
         binance_df = pd.read_pickle(local_root_directory + filename)
 
     return binance_df
 
-def save_equity_daily_data(data_df = None, ticker=None, provider = 'napoleon', starting_date=None,running_date=None,local_root_directory=None):
-    filename = ticker + '_' + starting_date.strftime('%d_%b_%Y') + '_' + running_date.strftime(
+def save_equity_daily_data(data_df = None, ticker=None, frequence=None, provider = 'napoleon', starting_date=None,running_date=None,local_root_directory=None):
+    filename = ticker + '_' + frequence + '_' + starting_date.strftime('%d_%b_%Y') + '_' + running_date.strftime(
         '%d_%b_%Y') + '_daily_returns.pkl'
     data_df.to_pickle(local_root_directory + filename)
 
