@@ -590,6 +590,11 @@ def get_accuracy_kpis(strategies, signals_df, under_returns_df):
     kpis_df = pd.DataFrame(results, columns=strategies, index=[accuracy.__name__])
     return kpis_df
 
+def filter_daily(dataframe):
+    dataframe['hour'] = dataframe.index.hour
+    dataframe = dataframe[dataframe['hour'] == 0]
+    dataframe = dataframe.drop(columns=['hour'])
+    return dataframe
 
 
 def get_kpi(price_df, default_metrics = [simple_return, annual_return, annual_volatility, sharpe, calmar, mdd]):
